==> haskell-hls-cabal-plugin-0.1.0.0-160-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-cabal-plugin
version:              0.1.0.0
visibility:           public
id:                   hls-cabal-plugin-0.1.0.0-H0Um0tlBb508gWN5B5GjKr
key:                  hls-cabal-plugin-0.1.0.0-H0Um0tlBb508gWN5B5GjKr
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  adb6f6cefce270bd4fe7f575eff144ed
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Diagnostics
    Ide.Plugin.Cabal.LicenseSuggest Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-cabal-plugin-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-cabal-plugin-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-0.1.0.0-H0Um0tlBb508gWN5B5GjKr
depends:
    Cabal-3.6.3.0 base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1
    directory-1.3.6.2 extra-1.7.14-JZwVFNOTzAl9wNXhTRS6o8
    ghcide-1.9.1.0-HwAkVTDd37EFvNbRQNs88T
    hashable-1.4.3.0-7566tBsT9J8EFScR3Tb2Bc
    hls-graph-1.9.0.0-4nTvQprVee21P1DngyVSFV
    hls-plugin-api-1.6.0.0-6Ebop0G4HfEC83Y5bnhsUu
    lsp-1.6.0.0-1JAbQDnc0SK1hycTz4LLrJ
    lsp-types-1.6.0.0-2bofF1fRSsb5ddfkj3rDHp
    regex-tdfa-1.3.2.2-G7ufGPI8BXGB521OJBI0lU stm-2.5.0.2 text-1.2.5.0
    unordered-containers-0.2.20-Kaqz4YtssULDpEsD0of7Qa

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-cabal-plugin-0.1.0.0-204-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-cabal-plugin
version:              0.1.0.0
visibility:           public
id:                   hls-cabal-plugin-0.1.0.0-3EnEQnGMsOsG99YhY0LjAD
key:                  hls-cabal-plugin-0.1.0.0-3EnEQnGMsOsG99YhY0LjAD
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  56844f2c26e634316e7a1a97a58e6b48
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Diagnostics
    Ide.Plugin.Cabal.LicenseSuggest Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-cabal-plugin-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-cabal-plugin-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-0.1.0.0-3EnEQnGMsOsG99YhY0LjAD
depends:
    Cabal-3.6.3.0 base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1
    directory-1.3.6.2 extra-1.7.15-9PmwGQvWkElDwGNWrixqMB
    ghcide-1.10.0.0-42asgJmBwLYDXfQ3kee4Wu
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    hls-graph-1.9.0.0-7y2pZvkYmIwHHyfFLNsbki
    hls-plugin-api-1.6.0.0-GBhVrEAXY9G7a8rlmXAPNi
    lsp-1.6.0.0-3mgfXrOs4nYBY8raCTSUiO
    lsp-types-1.6.0.0-fIIuT8laV65dJgS55XZCb
    regex-tdfa-1.3.2.2-9KQuOdDpiBL9UBsQEK6k8E stm-2.5.0.2 text-1.2.5.0
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
